@@ -11,6 +11,7 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+from .analytics import handle_analytics_post
 from .api_key_protector import api_key_protector
 from .dashboard import handle_dashboard_api
 from .signin import handle_emailpassword_signin_api
@@ -49,4 +50,5 @@ __all__ = [
     "handle_email_verify_token_post",
     "handle_emailpassword_signin_api",
     "handle_emailpassword_signout_api",
+    "handle_analytics_post",
 ]
