@@ -48,6 +48,7 @@ from supertokens_python.utils import Awaitable
 
 from ...normalised_url_path import NormalisedURLPath
 from .constants import (
+    DASHBOARD_ANALYTICS_API,
     DASHBOARD_API,
     EMAIL_PASSSWORD_SIGNOUT,
     EMAIL_PASSWORD_SIGN_IN,
@@ -237,6 +238,8 @@ def get_api_if_matched(path: NormalisedURLPath, method: str) -> Optional[str]:
         return EMAIL_PASSWORD_SIGN_IN
     if path_str.endswith(EMAIL_PASSSWORD_SIGNOUT) and method == "post":
         return EMAIL_PASSSWORD_SIGNOUT
+    if path_str.endswith(DASHBOARD_ANALYTICS_API) and method == "post":
+        return DASHBOARD_ANALYTICS_API
 
     return None
 
