@@ -11,18 +11,23 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from supertokens_python.recipe.openid.interfaces import (APIInterface,
-                                                         APIOptions)
-from supertokens_python.utils import send_200_response
+from supertokens_python.recipe.openid.interfaces import APIInterface, APIOptions
+from supertokens_python.utils import default_user_context, send_200_response
 
 from ..interfaces import OpenIdDiscoveryConfigurationGetResponse
 
 
-async def open_id_discovery_configuration_get(api_implementation: APIInterface, api_options: APIOptions):
+async def open_id_discovery_configuration_get(
+    api_implementation: APIInterface, api_options: APIOptions
+):
     if api_implementation.disable_open_id_discovery_configuration_get:
         return None
 
-    result = await api_implementation.open_id_discovery_configuration_get(api_options, {})
+    user_context = default_user_context(api_options.request)
+
+    result = await api_implementation.open_id_discovery_configuration_get(
+        api_options, user_context
+    )
 
     if isinstance(result, OpenIdDiscoveryConfigurationGetResponse):
         api_options.response.set_header("Access-Control-Allow-Origin", "*")
