@@ -13,16 +13,26 @@
 # under the License.
 from typing import List, Union
 
-from supertokens_python.ingredients.emaildelivery import \
-    EmailDeliveryIngredient
-from supertokens_python.ingredients.emaildelivery.types import SMTPServiceInterface, EmailDeliveryInterface
+from supertokens_python.ingredients.emaildelivery import EmailDeliveryIngredient
+from supertokens_python.ingredients.emaildelivery.types import (
+    SMTPServiceInterface,
+    EmailDeliveryInterface,
+)
 from supertokens_python.ingredients.smsdelivery import SMSDeliveryIngredient
-from supertokens_python.ingredients.smsdelivery.types import TwilioServiceInterface, SMSDeliveryInterface
+from supertokens_python.ingredients.smsdelivery.types import (
+    TwilioServiceInterface,
+    SMSDeliveryInterface,
+)
 
 
 class User:
-    def __init__(self, user_id: str,
-                 email: Union[str, None], phone_number: Union[str, None], time_joined: int):
+    def __init__(
+        self,
+        user_id: str,
+        email: Union[str, None],
+        phone_number: Union[str, None],
+        time_joined: int,
+    ):
         self.user_id: str = user_id
         self.email: Union[str, None] = email
         self.phone_number: Union[str, None] = phone_number
@@ -37,13 +47,14 @@ class DeviceCode:
 
 
 class DeviceType:
-    def __init__(self,
-                 pre_auth_session_id: str,
-                 failed_code_input_attempt_count: int,
-                 codes: List[DeviceCode],
-                 email: Union[str, None] = None,
-                 phone_number: Union[str, None] = None
-                 ):
+    def __init__(
+        self,
+        pre_auth_session_id: str,
+        failed_code_input_attempt_count: int,
+        codes: List[DeviceCode],
+        email: Union[str, None] = None,
+        phone_number: Union[str, None] = None,
+    ):
         self.pre_auth_session_id = pre_auth_session_id
         self.failed_code_input_attempt_count = failed_code_input_attempt_count
         self.codes = codes
@@ -52,12 +63,14 @@ class DeviceType:
 
 
 class CreateAndSendCustomEmailParameters:
-    def __init__(self,
-                 code_life_time: int,
-                 pre_auth_session_id: str,
-                 email: str,
-                 user_input_code: Union[str, None] = None,
-                 url_with_link_code: Union[str, None] = None):
+    def __init__(
+        self,
+        code_life_time: int,
+        pre_auth_session_id: str,
+        email: str,
+        user_input_code: Union[str, None] = None,
+        url_with_link_code: Union[str, None] = None,
+    ):
         self.email: str = email
         self.code_life_time: int = code_life_time
         self.pre_auth_session_id: str = pre_auth_session_id
@@ -69,13 +82,14 @@ PasswordlessLoginEmailTemplateVars = CreateAndSendCustomEmailParameters
 
 
 class CreateAndSendCustomTextMessageParameters:
-    def __init__(self,
-                 code_life_time: int,
-                 pre_auth_session_id: str,
-                 phone_number: str,
-                 user_input_code: Union[str, None] = None,
-                 url_with_link_code: Union[str, None] = None,
-                 ):
+    def __init__(
+        self,
+        code_life_time: int,
+        pre_auth_session_id: str,
+        phone_number: str,
+        user_input_code: Union[str, None] = None,
+        url_with_link_code: Union[str, None] = None,
+    ):
         self.code_life_time: int = code_life_time
         self.pre_auth_session_id: str = pre_auth_session_id
         self.phone_number: str = phone_number
@@ -98,9 +112,10 @@ SMSDeliveryOverrideInput = SMSDeliveryInterface[SMSTemplateVars]
 
 
 class PasswordlessIngredients:
-    def __init__(self,
-                 email_delivery: Union[EmailDeliveryIngredient[EmailTemplateVars], None] = None,
-                 sms_delivery: Union[SMSDeliveryIngredient[SMSTemplateVars], None] = None,
-                 ):
+    def __init__(
+        self,
+        email_delivery: Union[EmailDeliveryIngredient[EmailTemplateVars], None] = None,
+        sms_delivery: Union[SMSDeliveryIngredient[SMSTemplateVars], None] = None,
+    ):
         self.email_delivery = email_delivery
         self.sms_delivery = sms_delivery
