@@ -129,7 +129,10 @@ async def test_the_generate_token_api_with_valid_input_email_not_verified(
         ),
         framework="fastapi",
         recipe_list=[
-            session.init(anti_csrf="VIA_TOKEN"),
+            session.init(
+                anti_csrf="VIA_TOKEN",
+                get_token_transfer_method=lambda _, __, ___: "cookie",
+            ),
             emailverification.init("OPTIONAL"),
             emailpassword.init(),
         ],
@@ -148,7 +151,6 @@ async def test_the_generate_token_api_with_valid_input_email_not_verified(
     response = email_verify_token_request(
         driver_config_client,
         cookies["sAccessToken"]["value"],
-        cookies["sIdRefreshToken"]["value"],
         response_1.headers.get("anti-csrf"),  # type: ignore
         user_id,
     )
@@ -169,7 +171,10 @@ async def test_the_generate_token_api_with_valid_input_email_verified_and_test_e
         ),
         framework="fastapi",
         recipe_list=[
-            session.init(anti_csrf="VIA_TOKEN"),
+            session.init(
+                anti_csrf="VIA_TOKEN",
+                get_token_transfer_method=lambda _, __, ___: "cookie",
+            ),
             emailverification.init("OPTIONAL"),
             emailpassword.init(),
         ],
@@ -192,7 +197,6 @@ async def test_the_generate_token_api_with_valid_input_email_verified_and_test_e
         response = email_verify_token_request(
             driver_config_client,
             cookies["sAccessToken"]["value"],
-            cookies["sIdRefreshToken"]["value"],
             response_1.headers.get("anti-csrf"),  # type: ignore
             user_id,
         )
@@ -215,7 +219,10 @@ async def test_the_generate_token_api_with_valid_input_no_session_and_check_outp
         ),
         framework="fastapi",
         recipe_list=[
-            session.init(anti_csrf="VIA_TOKEN"),
+            session.init(
+                anti_csrf="VIA_TOKEN",
+                get_token_transfer_method=lambda _, __, ___: "cookie",
+            ),
             emailverification.init("OPTIONAL"),
             emailpassword.init(),
         ],
@@ -243,7 +250,10 @@ async def test_the_generate_token_api_with_an_expired_access_token_and_see_that_
         ),
         framework="fastapi",
         recipe_list=[
-            session.init(anti_csrf="VIA_TOKEN"),
+            session.init(
+                anti_csrf="VIA_TOKEN",
+                get_token_transfer_method=lambda _, __, ___: "cookie",
+            ),
             emailverification.init("OPTIONAL"),
             emailpassword.init(),
         ],
@@ -263,7 +273,6 @@ async def test_the_generate_token_api_with_an_expired_access_token_and_see_that_
     response_2 = email_verify_token_request(
         driver_config_client,
         cookies["sAccessToken"]["value"],
-        cookies["sIdRefreshToken"]["value"],
         response_1.headers.get("anti-csrf"),  # type: ignore
         user_id,
     )
@@ -280,7 +289,6 @@ async def test_the_generate_token_api_with_an_expired_access_token_and_see_that_
         },
         cookies={
             "sRefreshToken": cookies["sRefreshToken"]["value"],
-            "sIdRefreshToken": cookies["sIdRefreshToken"]["value"],
         },
     )
 
@@ -290,7 +298,6 @@ async def test_the_generate_token_api_with_an_expired_access_token_and_see_that_
     response_4 = email_verify_token_request(
         driver_config_client,
         cookies1["sAccessToken"]["value"],
-        cookies1["sIdRefreshToken"]["value"],
         response_3.headers.get("anti-csrf"),  # type: ignore
         user_id,
     )
@@ -324,7 +331,10 @@ async def test_that_providing_your_own_email_callback_and_make_sure_it_is_called
         ),
         framework="fastapi",
         recipe_list=[
-            session.init(anti_csrf="VIA_TOKEN"),
+            session.init(
+                anti_csrf="VIA_TOKEN",
+                get_token_transfer_method=lambda _, __, ___: "cookie",
+            ),
             emailverification.init(
                 mode="REQUIRED", create_and_send_custom_email=custom_f
             ),
@@ -345,7 +355,6 @@ async def test_that_providing_your_own_email_callback_and_make_sure_it_is_called
     response_2 = email_verify_token_request(
         driver_config_client,
         cookies["sAccessToken"]["value"],
-        cookies["sIdRefreshToken"]["value"],
         response_1.headers.get("anti-csrf"),  # type: ignore
         user_id,
     )
@@ -379,7 +388,10 @@ async def test_the_email_verify_api_with_valid_input(driver_config_client: TestC
         ),
         framework="fastapi",
         recipe_list=[
-            session.init(anti_csrf="VIA_TOKEN"),
+            session.init(
+                anti_csrf="VIA_TOKEN",
+                get_token_transfer_method=lambda _, __, ___: "cookie",
+            ),
             emailverification.init(
                 mode="REQUIRED", create_and_send_custom_email=custom_f
             ),
@@ -400,7 +412,6 @@ async def test_the_email_verify_api_with_valid_input(driver_config_client: TestC
     response_2 = email_verify_token_request(
         driver_config_client,
         cookies["sAccessToken"]["value"],
-        cookies["sIdRefreshToken"]["value"],
         response_1.headers.get("anti-csrf"),  # type: ignore
         user_id,
     )
@@ -419,7 +430,6 @@ async def test_the_email_verify_api_with_valid_input(driver_config_client: TestC
         },
         cookies={
             "sRefreshToken": cookies["sRefreshToken"]["value"],
-            "sIdRefreshToken": cookies["sIdRefreshToken"]["value"],
         },
         json={"method": "token", "token": token},
     )
@@ -449,7 +459,10 @@ async def test_the_email_verify_api_with_invalid_token_and_check_error(
         ),
         framework="fastapi",
         recipe_list=[
-            session.init(anti_csrf="VIA_TOKEN"),
+            session.init(
+                anti_csrf="VIA_TOKEN",
+                get_token_transfer_method=lambda _, __, ___: "cookie",
+            ),
             emailverification.init(
                 mode="REQUIRED", create_and_send_custom_email=custom_f
             ),
@@ -470,7 +483,6 @@ async def test_the_email_verify_api_with_invalid_token_and_check_error(
     response_2 = email_verify_token_request(
         driver_config_client,
         cookies["sAccessToken"]["value"],
-        cookies["sIdRefreshToken"]["value"],
         response_1.headers.get("anti-csrf"),  # type: ignore
         user_id,
     )
@@ -489,7 +501,6 @@ async def test_the_email_verify_api_with_invalid_token_and_check_error(
         },
         cookies={
             "sRefreshToken": cookies["sRefreshToken"]["value"],
-            "sIdRefreshToken": cookies["sIdRefreshToken"]["value"],
         },
         json={"method": "token", "token": "bad token"},
     )
@@ -519,7 +530,10 @@ async def test_the_email_verify_api_with_token_of_not_type_string(
         ),
         framework="fastapi",
         recipe_list=[
-            session.init(anti_csrf="VIA_TOKEN"),
+            session.init(
+                anti_csrf="VIA_TOKEN",
+                get_token_transfer_method=lambda _, __, ___: "cookie",
+            ),
             emailverification.init(
                 mode="REQUIRED", create_and_send_custom_email=custom_f
             ),
@@ -540,7 +554,6 @@ async def test_the_email_verify_api_with_token_of_not_type_string(
     response_2 = email_verify_token_request(
         driver_config_client,
         cookies["sAccessToken"]["value"],
-        cookies["sIdRefreshToken"]["value"],
         response_1.headers.get("anti-csrf"),  # type: ignore
         user_id,
     )
@@ -559,7 +572,6 @@ async def test_the_email_verify_api_with_token_of_not_type_string(
         },
         cookies={
             "sRefreshToken": cookies["sRefreshToken"]["value"],
-            "sIdRefreshToken": cookies["sIdRefreshToken"]["value"],
         },
         json={"method": "token", "token": 200},
     )
@@ -612,7 +624,10 @@ async def test_that_the_handle_post_email_verification_callback_is_called_on_suc
         ),
         framework="fastapi",
         recipe_list=[
-            session.init(anti_csrf="VIA_TOKEN"),
+            session.init(
+                anti_csrf="VIA_TOKEN",
+                get_token_transfer_method=lambda _, __, ___: "cookie",
+            ),
             emailverification.init(
                 mode="REQUIRED",
                 create_and_send_custom_email=custom_f,
@@ -635,7 +650,6 @@ async def test_that_the_handle_post_email_verification_callback_is_called_on_suc
     response_2 = email_verify_token_request(
         driver_config_client,
         cookies["sAccessToken"]["value"],
-        cookies["sIdRefreshToken"]["value"],
         response_1.headers.get("anti-csrf"),  # type: ignore
         user_id,
     )
@@ -654,7 +668,6 @@ async def test_that_the_handle_post_email_verification_callback_is_called_on_suc
         },
         cookies={
             "sRefreshToken": cookies["sRefreshToken"]["value"],
-            "sIdRefreshToken": cookies["sIdRefreshToken"]["value"],
         },
         json={"method": "token", "token": token},
     )
@@ -691,7 +704,10 @@ async def test_the_email_verify_with_valid_input_using_the_get_method(
         ),
         framework="fastapi",
         recipe_list=[
-            session.init(anti_csrf="VIA_TOKEN"),
+            session.init(
+                anti_csrf="VIA_TOKEN",
+                get_token_transfer_method=lambda _, __, ___: "cookie",
+            ),
             emailverification.init(
                 mode="REQUIRED",
                 create_and_send_custom_email=custom_f,
@@ -713,7 +729,6 @@ async def test_the_email_verify_with_valid_input_using_the_get_method(
     response_2 = email_verify_token_request(
         driver_config_client,
         cookies["sAccessToken"]["value"],
-        cookies["sIdRefreshToken"]["value"],
         response_1.headers.get("anti-csrf"),  # type: ignore
         user_id,
     )
@@ -742,7 +757,6 @@ async def test_the_email_verify_with_valid_input_using_the_get_method(
         },
         cookies={
             "sAccessToken": cookies["sAccessToken"]["value"],
-            "sIdRefreshToken": cookies["sIdRefreshToken"]["value"],
         },
     )
 
@@ -764,7 +778,10 @@ async def test_the_email_verify_with_no_session_using_the_get_method(
         ),
         framework="fastapi",
         recipe_list=[
-            session.init(anti_csrf="VIA_TOKEN"),
+            session.init(
+                anti_csrf="VIA_TOKEN",
+                get_token_transfer_method=lambda _, __, ___: "cookie",
+            ),
             emailverification.init("OPTIONAL"),
             emailpassword.init(),
         ],
@@ -821,7 +838,10 @@ async def test_the_email_verify_api_with_valid_input_overriding_apis(
         ),
         framework="fastapi",
         recipe_list=[
-            session.init(anti_csrf="VIA_TOKEN"),
+            session.init(
+                anti_csrf="VIA_TOKEN",
+                get_token_transfer_method=lambda _, __, ___: "cookie",
+            ),
             emailverification.init(
                 mode="REQUIRED",
                 create_and_send_custom_email=custom_f,
@@ -844,7 +864,6 @@ async def test_the_email_verify_api_with_valid_input_overriding_apis(
     response_2 = email_verify_token_request(
         driver_config_client,
         cookies["sAccessToken"]["value"],
-        cookies["sIdRefreshToken"]["value"],
         response_1.headers.get("anti-csrf"),  # type: ignore
         user_id,
     )
@@ -916,7 +935,10 @@ async def test_the_email_verify_api_with_valid_input_overriding_apis_throws_erro
         ),
         framework="fastapi",
         recipe_list=[
-            session.init(anti_csrf="VIA_TOKEN"),
+            session.init(
+                anti_csrf="VIA_TOKEN",
+                get_token_transfer_method=lambda _, __, ___: "cookie",
+            ),
             emailverification.init(
                 mode="REQUIRED",
                 create_and_send_custom_email=custom_f,
@@ -941,7 +963,6 @@ async def test_the_email_verify_api_with_valid_input_overriding_apis_throws_erro
     response_2 = email_verify_token_request(
         driver_config_client,
         cookies["sAccessToken"]["value"],
-        cookies["sIdRefreshToken"]["value"],
         response_1.headers.get("anti-csrf"),  # type: ignore
         user_id,
     )
@@ -983,7 +1004,10 @@ async def test_the_generate_token_api_with_valid_input_and_then_remove_token(
         ),
         framework="fastapi",
         recipe_list=[
-            session.init(anti_csrf="VIA_TOKEN"),
+            session.init(
+                anti_csrf="VIA_TOKEN",
+                get_token_transfer_method=lambda _, __, ___: "cookie",
+            ),
             emailverification.init("OPTIONAL"),
             emailpassword.init(),
         ],
@@ -1024,7 +1048,10 @@ async def test_the_generate_token_api_with_valid_input_verify_and_then_unverify_
         ),
         framework="fastapi",
         recipe_list=[
-            session.init(anti_csrf="VIA_TOKEN"),
+            session.init(
+                anti_csrf="VIA_TOKEN",
+                get_token_transfer_method=lambda _, __, ___: "cookie",
+            ),
             emailverification.init(mode="OPTIONAL"),
             emailpassword.init(),
         ],
@@ -1065,7 +1092,7 @@ async def test_email_verify_with_deleted_user(driver_config_client: TestClient):
         [
             emailpassword.init(),
             emailverification.init("OPTIONAL", create_and_send_custom_email=custom_f),
-            session.init(),
+            session.init(get_token_transfer_method=lambda _, __, ___: "cookie"),
         ]
     )
     init(**st_args)
@@ -1085,7 +1112,6 @@ async def test_email_verify_with_deleted_user(driver_config_client: TestClient):
     response = email_verify_token_request(
         driver_config_client,
         cookies["sAccessToken"]["value"],
-        cookies["sIdRefreshToken"]["value"],
         res.headers.get("anti-csrf"),  # type: ignore
         user_id,
     )
@@ -1109,7 +1135,7 @@ async def test_generate_email_verification_token_api_updates_session_claims(
                 emailverification.init(
                     "OPTIONAL", create_and_send_custom_email=custom_f
                 ),
-                session.init(),
+                session.init(get_token_transfer_method=lambda _, __, ___: "cookie"),
             ]
         )
     )
@@ -1123,7 +1149,6 @@ async def test_generate_email_verification_token_api_updates_session_claims(
 
     user_id = dict_res["user"]["id"]
     cookies = extract_all_cookies(res)
-    refresh_token = cookies["sIdRefreshToken"]["value"]
 
     # Start verification:
     verify_token = await create_email_verification_token(user_id)
@@ -1133,7 +1158,6 @@ async def test_generate_email_verification_token_api_updates_session_claims(
     res = email_verify_token_request(
         driver_config_client,
         cookies["sAccessToken"]["value"],
-        refresh_token,
         res.headers.get("anti-csrf"),  # type: ignore
         user_id,
     )
@@ -1149,7 +1173,6 @@ async def test_generate_email_verification_token_api_updates_session_claims(
     res = email_verify_token_request(
         driver_config_client,
         cookies["sAccessToken"]["value"],
-        refresh_token,
         res.headers.get("anti-csrf"),  # type: ignore
         user_id,
     )
@@ -1162,7 +1185,6 @@ async def test_generate_email_verification_token_api_updates_session_claims(
     res = email_verify_token_request(
         driver_config_client,
         cookies["sAccessToken"]["value"],
-        refresh_token,
         res.headers.get("anti-csrf"),  # type: ignore
         user_id,
     )
@@ -1176,7 +1198,6 @@ async def test_generate_email_verification_token_api_updates_session_claims(
     res = email_verify_token_request(
         driver_config_client,
         cookies["sAccessToken"]["value"],
-        refresh_token,
         res.headers.get("anti-csrf"),  # type: ignore
         user_id,
     )
