@@ -31,16 +31,20 @@ from supertokens_python.ingredients.emaildelivery.types import (
     SMTPSettings,
     SMTPSettingsFrom,
 )
-from supertokens_python.recipe import session, thirdparty, emailverification
+from supertokens_python.recipe import emailverification, session, thirdparty
+from supertokens_python.recipe.emailverification.emaildelivery.services.smtp import (
+    SMTPService,
+)
+from supertokens_python.recipe.emailverification.types import User as EVUser
+from supertokens_python.recipe.emailverification.types import (
+    VerificationEmailTemplateVars,
+)
 from supertokens_python.recipe.session import SessionRecipe
 from supertokens_python.recipe.session.recipe_implementation import (
     RecipeImplementation as SessionRecipeImplementation,
 )
 from supertokens_python.recipe.session.session_functions import create_new_session
 from supertokens_python.recipe.thirdparty.asyncio import sign_in_up
-from supertokens_python.recipe.emailverification.emaildelivery.services.smtp import (
-    SMTPService,
-)
 from supertokens_python.recipe.thirdparty.interfaces import SignInUpOkResult
 from supertokens_python.recipe.thirdparty.provider import Provider
 from supertokens_python.recipe.thirdparty.types import (
@@ -50,10 +54,6 @@ from supertokens_python.recipe.thirdparty.types import (
     UserInfoEmail,
 )
 from tests.utils import clean_st, email_verify_token_request, reset, setup_st, start_st
-from supertokens_python.recipe.emailverification.types import (
-    User as EVUser,
-    VerificationEmailTemplateVars,
-)
 
 respx_mock = respx.MockRouter
 
@@ -137,7 +137,7 @@ async def test_email_verify_default_backward_compatibility(
                     providers=[CustomProvider("CUSTOM", True)]
                 )
             ),
-            session.init(),
+            session.init(get_token_transfer_method=lambda _, __, ___: "cookie"),
         ],
     )
     start_st()
@@ -149,7 +149,7 @@ async def test_email_verify_default_backward_compatibility(
         raise Exception("Should never come here")
     assert isinstance(resp, SignInUpOkResult)
     user_id = resp.user.user_id
-    response = await create_new_session(s.recipe_implementation, user_id, {}, {})
+    response = await create_new_session(s.recipe_implementation, user_id, True, {}, {})
 
     def api_side_effect(request: httpx.Request):
         nonlocal app_name, email, email_verify_url
@@ -169,7 +169,6 @@ async def test_email_verify_default_backward_compatibility(
         resp = email_verify_token_request(
             driver_config_client,
             response["accessToken"]["token"],
-            response["idRefreshToken"]["token"],
             response.get("antiCsrf", ""),
             user_id,
             True,
@@ -208,7 +207,7 @@ async def test_email_verify_default_backward_compatibility_supress_error(
                     providers=[CustomProvider("CUSTOM", True)]
                 )
             ),
-            session.init(),
+            session.init(get_token_transfer_method=lambda _, __, ___: "cookie"),
         ],
     )
     start_st()
@@ -220,7 +219,7 @@ async def test_email_verify_default_backward_compatibility_supress_error(
         raise Exception("Should never come here")
     assert isinstance(resp, SignInUpOkResult)
     user_id = resp.user.user_id
-    response = await create_new_session(s.recipe_implementation, user_id, {}, {})
+    response = await create_new_session(s.recipe_implementation, user_id, True, {}, {})
 
     def api_side_effect(request: httpx.Request):
         nonlocal app_name, email, email_verify_url
@@ -240,7 +239,6 @@ async def test_email_verify_default_backward_compatibility_supress_error(
         resp = email_verify_token_request(
             driver_config_client,
             response["accessToken"]["token"],
-            response["idRefreshToken"]["token"],
             response.get("antiCsrf", ""),
             user_id,
             True,
@@ -287,7 +285,7 @@ async def test_email_verify_backward_compatibility(driver_config_client: TestCli
                     providers=[CustomProvider("CUSTOM", True)]
                 )
             ),
-            session.init(),
+            session.init(get_token_transfer_method=lambda _, __, ___: "cookie"),
         ],
     )
     start_st()
@@ -299,12 +297,11 @@ async def test_email_verify_backward_compatibility(driver_config_client: TestCli
         raise Exception("Should never come here")
     assert isinstance(resp, SignInUpOkResult)
     user_id = resp.user.user_id
-    response = await create_new_session(s.recipe_implementation, user_id, {}, {})
+    response = await create_new_session(s.recipe_implementation, user_id, True, {}, {})
 
     resp = email_verify_token_request(
         driver_config_client,
         response["accessToken"]["token"],
-        response["idRefreshToken"]["token"],
         response.get("antiCsrf", ""),
         user_id,
         True,
@@ -362,7 +359,7 @@ async def test_email_verify_custom_override(driver_config_client: TestClient):
                     providers=[CustomProvider("CUSTOM", True)]
                 ),
             ),
-            session.init(),
+            session.init(get_token_transfer_method=lambda _, __, ___: "cookie"),
         ],
     )
     start_st()
@@ -375,7 +372,7 @@ async def test_email_verify_custom_override(driver_config_client: TestClient):
     assert isinstance(resp, SignInUpOkResult)
     user_id = resp.user.user_id
     assert isinstance(user_id, str)
-    response = await create_new_session(s.recipe_implementation, user_id, {}, {})
+    response = await create_new_session(s.recipe_implementation, user_id, True, {}, {})
 
     def api_side_effect(request: httpx.Request):
         nonlocal app_name, email, email_verify_url
@@ -392,7 +389,6 @@ async def test_email_verify_custom_override(driver_config_client: TestClient):
         resp = email_verify_token_request(
             driver_config_client,
             response["accessToken"]["token"],
-            response["idRefreshToken"]["token"],
             response.get("antiCsrf", ""),
             user_id,
             True,
@@ -499,7 +495,7 @@ async def test_email_verify_smtp_service(driver_config_client: TestClient):
                     providers=[CustomProvider("CUSTOM", True)]
                 ),
             ),
-            session.init(),
+            session.init(get_token_transfer_method=lambda _, __, ___: "cookie"),
         ],
     )
     start_st()
@@ -512,12 +508,11 @@ async def test_email_verify_smtp_service(driver_config_client: TestClient):
     assert isinstance(resp, SignInUpOkResult)
     user_id = resp.user.user_id
     assert isinstance(user_id, str)
-    response = await create_new_session(s.recipe_implementation, user_id, {}, {})
+    response = await create_new_session(s.recipe_implementation, user_id, True, {}, {})
 
     resp = email_verify_token_request(
         driver_config_client,
         response["accessToken"]["token"],
-        response["idRefreshToken"]["token"],
         response.get("antiCsrf", ""),
         user_id,
         True,
